/*
	hostlib allows developers to check if a certain key is the world's host or has
	host privleges, on both UNIX and Windows. It first checks the world.host variable,
	and if it is not set (per UNIX or if it could not be determined from the Windows
	pager), it falls back to checking the world's configurations.

	This library depends on world.GetConfig() for its information, so you can give players
	a "host status" by using a call like world.SetConfig("admin", "George", "role=owner")

	This also means that various files on the user's system are respected, such as admin.txt.
	This allows for the person hosting the world to give permissions to keys as they see fit,
	which should be the desired (if the person hosting the game wants to set another player to
	be treated with hosting privileges they can do it themselves and hosts on Unix machines can
	set a host key for their Dream Daemon instances.

	The limitation to this is that someone on Windows hosting as a Guest key will not register
	as the world's host, as IP-checking is beyond the scope of this proc.
*/

proc/IsHost(key)
	if(!cmptext(key, world.host)) // Use world.host by default, fall back to admin.txt
		var/list/admin = world.GetConfig("admin")

		for(var/k in admin)
			if(cmptext(ckey(k), key))
				var/list/props = params2list(admin[k])
				if(("role" in props) && \
					(cmptext(props["role"],"owner") || cmptext(props["role"],"root")))
					return TRUE
				else break

		return FALSE

	else return TRUE
